@@ -1,24 +1,25 @@
 """
 TensorFlow functional helper utilities.
 """
-
-from typing import Any, Tuple
+from typing import Tuple
 
 import tensorflow as tf  # type: ignore
 
+from targetran._typing import ArrayLike
 
-def _tf_convert(x: Any) -> tf.Tensor:
+
+def _tf_convert(x: ArrayLike) -> tf.Tensor:
     if isinstance(x, tf.Tensor):
-        return tf.cast(x, dtype=tf.float32)
-    return tf.convert_to_tensor(x, dtype=tf.float32)
+        return tf.cast(x, tf.float32)
+    return tf.convert_to_tensor(x, tf.float32)
 
 
 def _tf_cast_to_int(x: tf.Tensor) -> tf.Tensor:
-    return tf.cast(x, dtype=tf.int32)
+    return tf.cast(x, tf.int32)
 
 
 def _tf_round_to_int(x: tf.Tensor) -> tf.Tensor:
-    return tf.cast(tf.math.rint(x), dtype=tf.int32)
+    return tf.cast(tf.math.rint(x), tf.int32)
 
 
 def _tf_pad_image(
