@@ -5,6 +5,7 @@ import functools
 import itertools
 from typing import Any, Callable, List, Optional, Sequence, Tuple
 
+import numpy as np
 import tensorflow as tf  # type: ignore
 
 from targetran._check import (
@@ -51,14 +52,15 @@ def to_tf(
     """
     Convert seqs to TF (eager) tensor seqs.
     """
-    tuples = [
-        (_tf_convert(image),
-         tf.reshape(_tf_convert(bboxes), (-1, 4)),
-         _tf_convert(labels))
-        for image, bboxes, labels in itertools.zip_longest(
+    tuples: List[Tuple[tf.Tensor, tf.Tensor, tf.Tensor]] = []
+    for image, bboxes, labels in itertools.zip_longest(  # type: ignore
             image_seq, bboxes_seq, labels_seq, fillvalue=[]
+    ):
+        tuples.append(
+            (_tf_convert(image),
+             tf.reshape(_tf_convert(bboxes), (-1, 4)),
+             _tf_convert(labels))
         )
-    ]
     tf_image_seq, tf_bboxes_seq, tf_labels_seq = tuple(zip(*tuples))
     return tf_image_seq, tf_bboxes_seq, tf_labels_seq
 
@@ -248,8 +250,9 @@ class TFRandomTransform:
     ) -> None:
         self._tf_fn = tf_fn
         self.probability = probability
-        self._rng = tf.random.Generator.from_seed(seed) if seed is not None \
-            else tf.random.Generator.from_non_deterministic_state()
+        self._rng = tf.random.Generator.from_seed(
+            seed if seed is not None else np.random.randint(1e6)  # type: ignore
+        )
         self.name = name
         self.is_affine = is_affine
 
